pub struct Args {Show 18 fields
pub input: String,
pub output: String,
pub backend: String,
pub directed: bool,
pub embedding_dim: usize,
pub split: f32,
pub walks_per_node: usize,
pub walk_length: usize,
pub window_size: usize,
pub batch_size: usize,
pub num_workers: usize,
pub num_epochs: usize,
pub num_negatives: usize,
pub seed: usize,
pub learning_rate: f64,
pub p: f32,
pub q: f32,
pub sample: f32,
}Expand description
CLI arguments
Fields
input- The input CSV. Needs to be provided.output- Where to store the outputs. Defaults to"/tmp/node2vec".directed- Shall the graph be treated as a directed graph. Defaults tofalse.embedding_dim- Size of the embedding to create. Defaults to16.split- How much of the data should be in the trainings data vs. validation data. Defaults to0.9.walks_per_node- Number of random walks to do per node. Defaults to20.walk_length- Length of the random walks. Defaults to20.window_size- Window size parameter for the skipgram model. Defaults to2.batch_size- Batch size during training. Defaults to256.num_workers- Number of workers to use during the generation of the batches. Defaults to4.num_epochs- Number of epochs to train the model for. Defaults to5.num_negatives- Number of negative examples to sample. Defaults to5.seed- Seed for reproducibility. Defaults to42.learning_rate- Learning rate for the Adam optimiser. Defaults to1-e3.p- p parameter for the node2vec random walks and controls the probability to return to origin node. Defaults to1.0.q- q parameter for node2vec random walks and controls the probability to venture on a different node from the origin node. Defaults to1.0.
Fields
input: Stringoutput: Stringbackend: Stringdirected: boolembedding_dim: usizesplit: f32walks_per_node: usizewalk_length: usizewindow_size: usizebatch_size: usizenum_workers: usizenum_epochs: usizenum_negatives: usizeseed: usizelearning_rate: f64p: f32q: f32sample: f32Trait Implementations
Sourceimpl Args for Args
impl Args for Args
Sourcefn augment_args<'b>(__clap_app: Command) -> Command
fn augment_args<'b>(__clap_app: Command) -> Command
Sourcefn augment_args_for_update<'b>(__clap_app: Command) -> Command
fn augment_args_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourceimpl CommandFactory for Args
impl CommandFactory for Args
Sourceimpl FromArgMatches for Args
impl FromArgMatches for Args
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Parser for Args
impl Parser for Args
Sourcefn parse_from<I, T>(itr: I) -> Self
fn parse_from<I, T>(itr: I) -> Self
Parse from iterator, exit on error.
Sourcefn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
fn try_parse_from<I, T>(itr: I) -> Result<Self, Error>
Parse from iterator, return Err on error.
Sourcefn update_from<I, T>(&mut self, itr: I)
fn update_from<I, T>(&mut self, itr: I)