Args

Struct Args 

pub struct Args {
Show 17 fields pub input: String, pub output: String, pub backend: String, pub directed: bool, pub embedding_dim: usize, pub split: f32, pub walks_per_node: usize, pub walk_length: usize, pub window_size: usize, pub batch_size: usize, pub num_workers: usize, pub num_epochs: usize, pub num_negatives: usize, pub seed: usize, pub learning_rate: f64, pub p: f32, pub q: f32,
}
CLI arguments

Fields

  • input - The input CSV. Needs to be provided.
  • output - Where to store the outputs. Defaults to "/tmp/node2vec".
  • directed - Shall the graph be treated as a directed graph. Defaults to false.
  • embedding_dim - Size of the embedding to create. Defaults to 16.
  • split - How much of the data should be in the trainings data vs. validation data. Defaults to 0.9.
  • walks_per_node - Number of random walks to do per node. Defaults to 20.
  • walk_length - Length of the random walks. Defaults to 20.
  • window_size - Window size parameter for the skipgram model. Defaults to 2.
  • batch_size - Batch size during training. Defaults to 256.
  • num_workers - Number of workers to use during the generation of the batches. Defaults to 4.
  • num_epochs - Number of epochs to train the model for. Defaults to 5.
  • num_negatives - Number of negative examples to sample. Defaults to 5.
  • seed - Seed for reproducibility. Defaults to 42.
  • learning_rate - Learning rate for the Adam optimiser. Defaults to 1-e3.
  • p - p parameter for the node2vec random walks and controls the probability to return to origin node. Defaults to 1.0.
  • q - q parameter for node2vec random walks and controls the probability to venture on a different node from the origin node. Defaults to 1.0.

Fields

input: Stringoutput: Stringbackend: Stringdirected: boolembedding_dim: usizesplit: f32walks_per_node: usizewalk_length: usizewindow_size: usizebatch_size: usizenum_workers: usizenum_epochs: usizenum_negatives: usizeseed: usizelearning_rate: f64p: f32q: f32